<?php
c_include('api/apiAdaptador');

e_include('ext_favoritos/class/listaDinamica');

/**
 * Eventos Api Adapter class for the Mideas Framework.
 *
 * @package		Mideas.Framework
 * @subpackage	Api
 * @since		1.0
 */
class FavoritosApiAdaptador extends ApiAdaptador
{
	protected $extension = 'favoritos';
	protected $carpeta = 'ext_favoritos';
	
	protected $elementos_permitidos = array("listaDinamica");
	
	protected $campos_ignorados_nuevo = array("id","fecha");
	protected $campos_multilang = array("titulo","contenido","lugar");
	
	public function __construct($elemento, $accion){
		parent::__construct($elemento, $accion);
		$this->mensajes = array("nuevo_ok"=>__("Se ha creado la lista de favoritos. Haz click <a href='%s'>aquí</a> para ver la nueva lista."), "nuevo_ko"=>__("Se ha producido un error al intentar crear la lista de favoritos"), "editar_ok"=>__("Se ha modificado la lista de favoritos. Haz click <a href='%s'>aquí</a> para visitar la página de la lista."));
	}
	
	function getNuevoFavorito(){
		if (!$this->checkAuth())
			return $this->error(__('Debes estar identificado para guardar favoritos en listas'));
			
		if (empty($_POST))
			return $this->error(__('Datos incorrectos'));
			
		if ($_POST['token'] != $this->autenticado)
			return $this->error(__('Token incorrecto'));
			
		if (empty($_POST['lista_dinamica_fav_id']))
			return $this->error(__('No se ha encontrado la lista'));
			
		$ld = new ListaDinamica();
		
		$ld->setid($_POST['lista_dinamica_fav_id']);
		
		$ld = $ld->BuscarId();
		
		if (!$ld || empty($ld->id))
			return $this->error(__('No se ha encontrado la lista'));
			
		if (empty($_POST['extension']) || empty($_POST['vista']) || empty($_POST['id']))
			return $this->error(__('No se ha encontrado el item'));
			
		$id_lg = $_POST['extension'] . '.' . $_POST['vista'] . '.' . $_POST['id'];
		
		$arr_fav = Helpers::toArray(json_decode($ld->favoritos));
		
		if (array_key_exists($id_lg, $ld->favoritos_formateados)){
			unset($arr_fav[$id_lg]);
			
			$json_fav = json_encode($arr_fav);
			
			$ld->setfavoritos($json_fav);
			
			$ld->Modificar();
			
			return $this->arrResp('removed', array('id_lista'=>$ld->id), 'removed');
		}
		
		$arr_new_fav = array("id"=>$id_lg, "imagen"=>$_POST['imagen'], "titulo"=>$_POST['titulo']);
		
		$arr_fav[$id_lg] = $arr_new_fav;
		
		$json_fav = json_encode($arr_fav);
			
		$ld->setfavoritos($json_fav);
		
		$ld->Modificar();
		
		return $this->arrResp(__('Item añadido con éxito a la lista'), array('id_lista'=>$ld->id), 'ok');
	}
	
	function getNuevoFavoritoEnSesion(){
		if (empty($_POST))
			return $this->error(__('Datos incorrectos'));
			
		if ($_POST['token'] != Helpers::getFormToken())
			return $this->error(__('Token incorrecto'));
			
		$ld = new ListaDinamica();
			
		if (empty($_POST['extension']) || empty($_POST['vista']) || empty($_POST['id']))
			return $this->error(__('No se ha encontrado el item'));
			
		$id_lg = $_POST['extension'] . '.' . $_POST['vista'] . '.' . $_POST['id'];
		
		$arr_fav = Helpers::getSesion()->get('favoritos.favoritos_sesion');
		
		if (is_array($arr_fav) && sizeof($arr_fav) > 0){
			if (array_key_exists($id_lg, $arr_fav)){
				unset($arr_fav[$id_lg]);
				if (is_array($arr_fav) && sizeof($arr_fav) > 0){
					Helpers::getSesion()->set('favoritos.favoritos_sesion', $arr_fav);
				} else {
					Helpers::getSesion()->clear('favoritos.favoritos_sesion');
				}
				
				return $this->arrResp('removed', array('item_lista_sesion'=>$id_lg), 'removed');
				
			}
		} else {
			$arr_fav = array();
		}
		
		$arr_new_fav = array("id"=>$id_lg, "imagen"=>$_POST['imagen'], "titulo"=>$_POST['titulo']);
		
		$arr_fav[$id_lg] = $arr_new_fav;
		
		Helpers::getSesion()->set('favoritos.favoritos_sesion', $arr_fav);
		
		return $this->arrResp(__('Item añadido con éxito a la lista'), array('item_lista_sesion'=>$id_lg), 'ok');
	}
	
	function getContarFavoritos(){
		$arr_fav = Helpers::getSesion()->get('favoritos.favoritos_sesion');
		
		if (is_array($arr_fav) && sizeof($arr_fav) > 0){
			$cuenta_favs = count($arr_fav);
		} else {
			$cuenta_favs = 0;
		}
		
		return $this->arrResp($cuenta_favs, array('total_favs'=>$cuenta_favs), 'ok');
	}
	
	function getContarFavoritosCat(){
		if (empty($_POST['extension']) || empty($_POST['catid'])){
			return $this->error(__('Datos incorrectos'));
		}
		
		$arr_fav = Helpers::getSesion()->get('favoritos.favoritos_sesion');
		
		if (is_array($arr_fav) && sizeof($arr_fav) > 0){
			$cuenta_favs = 0;
			foreach ($arr_fav as $kfav=>$fav){
				$exp_fav = explode('.', $fav['id']);
					
				$ext_com = new ExtCom(array("extension" => $exp_fav[0], "vista" => $exp_fav[1], "id_elemento" => $exp_fav[2]));

				$fav_conector = $ext_com->getData('array');
				
				$cats_conector = (array) json_decode($fav_conector['obj']->categorias);
				
				if ($fav_conector['extension'] == $_POST['extension'] && in_array($_POST['catid'], $cats_conector)){
					$cuenta_favs += 1;
				}
			}
		} else {
			$cuenta_favs = 0;
		}
		
		return $this->arrResp($cuenta_favs, array('total_favs'=>$cuenta_favs), 'ok');
	}
	
	function getCompartirListaSesion(){
		if (empty($_POST))
			return $this->error(__('Datos incorrectos'));
			
		if ($_POST['token'] != Helpers::getFormToken())
			return $this->error(__('Token incorrecto'));
			
		$arr_fav = Helpers::getSesion()->get('favoritos.favoritos_sesion');
		
		if (is_array($arr_fav) && sizeof($arr_fav) > 0){
			
			$ld = new ListaDinamica();
		
			$posted = array();
			
			$titulo_lista = sprintf(__('Gift List %s'), strftime("%d-%m-%Y %H:%M:%S", time()));
			
			$posted["ext_favoritos"]["detalles"]["titulo"] = array(SistemaIdioma::getIdiomaSesion() => $titulo_lista);
			$posted["ext_favoritos"]["detalles"]["fecha_publicacion"] = strftime("%Y-%m-%d %H:%M:%S", time());
			$posted["ext_favoritos"]["detalles"]["estado"] = 1;
			$posted["ext_favoritos"]["detalles"]["categorias"] = array("1");
			
			$posted["ext_favoritos"]["detalles"]["favoritos"] = $arr_fav;
			
			$posted["ext_favoritos"]["detalles"]["accion"] = "nuevo";
			
			$save_posted = $ld->guardarPost($posted);
			
			if ($save_posted === true){
				ItemsIndex::BorrarTodosItems(array("ext_favoritos"));
				
				$ld_new = new ListaDinamica();
				
				$ld_new = $ld_new->Listar('titulo LIKE "%'.$titulo_lista.'%" AND estado="1"');
				
				if (is_array($ld_new) && sizeof($ld_new) == 1){
					$ld_new = $ld_new[0];
					
					$data = array("url"=>$ld_new->getLink(false, null, true));
					
					//Helpers::getSesion()->clear('favoritos.favoritos_sesion');
					
					return $this->arrResp(sprintf(__('Lista de favoritos generada con éxito en %s'), $data['url']), $data, 'ok');
				} else {
					return $this->error(__('¡No se ha encontrado la lista de favoritos!'));
				}
			} else {
				return $this->error($save_posted);
			}
			
			
		} else {
			return $this->error(__('¡No se ha podido crear la lista de favoritos porque no hay ningún favorito!'));
		}
	}
}