<?php

defined('CONF_URL_APP') or die;

class ListaDinamica extends ItemModel {

    protected $dbt_const = "DBT_FAVORITOS_LISTAS_DINAMICAS";
    protected $dbt = "favoritos_listas_dinamicas";
    protected $ext_folder = "ext_favoritos";
    protected $ext_vista_categoria = "categoria_favoritos";
    protected $ext_vista_item = "lista_dinamica";
    protected $ext_item_class = "ListaDinamica";
    protected $ext_categoria_class = "FavoritoCategoria";
    protected $ext_item_campoextra_class = "ListaDinamicaCampoExtra";
    protected $all_vars = array("id", "titulo", "alias", "contenido", "fecha", "fecha_publicacion", "estado", "imagen_destacada", "categorias", "creador", "creador_alias","propietario", "params", "tags", "idioma", "lugar", "direccion", "codigo_postal", "localidad", "provincia", "pais", "latitud", "longitud", "location", "acceso", "favoritos","id_original");
    protected $idx_vars = array("id");
    protected $update_vars = array("titulo", "alias", "contenido", "fecha_publicacion", "estado", "imagen_destacada", "categorias", "creador", "creador_alias","propietario", "params", "tags", "idioma", "lugar", "direccion", "codigo_postal", "localidad", "provincia", "pais", "latitud", "longitud", "location", "acceso", "favoritos","id_original");
    protected $campos_multilang = array("titulo", "alias", "contenido", "lugar");
    protected $campos_array = array("params", "categorias", "favoritos");
    protected $campo_elementos = "favoritos";

    function __construct() {
        parent::__construct();
    }

    function includes() {
        c_include('loc/region', 'loc/provincia', 'loc/localidad', 'loc/pais', 'helpers/extCom');
        e_include('ext_favoritos/class/favoritoCategoria');
    }

    function getimagen_destacada($w, $h) {
        if (empty($w))
            $w = 300;

        if (empty($h))
            $h = 200;

        if (!is_array($this->favoritos_formateados)) {
            $img_dest = Helpers::getImagenDesaparecida($w, $h);
        } else {
            $img_encontrada = false;
            $arr_imgs = array();
			foreach ($this->favoritos_formateados as $ff) {
				$arr_img['image'] = CONF_URL_APP.$ff['conector']['obj']->imagen_destacada;
				/*var_dumpre($arr_img);
				exit;
				parse_str($ff['imagen'], $arr_img);*/
				
                if (!empty($arr_img['image']) && $arr_img['image'] != CONF_URL_APP . Helpers::getImagenDesaparecida(0,0,'noimage',true)) {
					$arr_imgs[] = $arr_img['image'];
				}
            }
			
			if (count($arr_imgs) > 1){
				$img_dest = self::generarImagenMultiple($arr_imgs, $w, $h);
			} else {
				$img_dest = Helpers::generateImageLink($arr_imgs[0], $w, $h);
			}
			
            if (empty($img_dest)) {
                $img_dest = Helpers::getImagenDesaparecida($w, $h);
            }
        }

        return $img_dest;
    }
	
	private static function generarImagenMultiple($imgs=array(), $w, $h){
		global $tileWidth, $pxBetweenTiles, $leftOffSet, $topOffSet, $numberOfTiles;
		
		$dir_path_img = CONF_REALPATH_APP . 'uploads/thumbs_listas';
		$path_img = $dir_path_img.'/'.md5(implode(';',$imgs).$w.$h).'.jpg';
		$url_img = CONF_URL_APP . 'uploads/thumbs_listas/'.md5(implode(';',$imgs).$w.$h).'.jpg';
		
		if (file_exists($path_img))
			return $url_img;
			
		$num_imgs = count($imgs);
		
		if ($num_imgs == 0)
			return '';
			
		if ($num_imgs > 6){
			$imgs = array_slice($imgs, 0, 6);
			$num_imgs = 6;
		}
		
		$tileWidth = $w / $num_imgs;
		$tileHeight = $h;
		$numberOfTiles = $num_imgs;
		$pxBetweenTiles = 0;
		$leftOffSet = $topOffSet = 0;
		
		$mapWidth = ($tileWidth + $pxBetweenTiles) * $numberOfTiles;
		$mapHeight = ($tileHeight + $pxBetweenTiles);
		 
		$mapImage = imagecreatetruecolor($mapWidth, $mapHeight);
		$bgColor = imagecolorallocate($mapImage, 235, 235, 235);
		imagefill($mapImage, 0, 0, $bgColor);
		 		 
		foreach ($imgs as $index => $srcImagePath)
		{
		 list ($x, $y) = self::indexToCoords($index);
		 if (substr($srcImagePath, -4) == ".png"){
			 $tileImg = imagecreatefrompng($srcImagePath);
		 } else {
		 	$tileImg = imagecreatefromjpeg($srcImagePath);
		 }

		 $tileImgWidth = imagesx($tileImg);
		 $tileImgHeight = imagesy($tileImg);
		 
		 $finalWidth = (int) (($tileImgHeight * $tileWidth) / $tileHeight);
		 
		 imagecopyresampled($mapImage, $tileImg, $x, $y, 0, 0, $tileWidth, $tileHeight, $finalWidth, $tileImgHeight);
		 imagedestroy($tileImg);
		}
		 
		/*
		 * RESCALE TO THUMB FORMAT
		 */

		$thumbImage = imagecreatetruecolor($w, $h);
		imagecopyresampled($thumbImage, $mapImage, 0, 0, 0, 0, $w, $h, $mapWidth, $mapHeight);
		
		if (!is_dir($dir_path_img)){
			Helpers::ftpCrearCarpeta($dir_path_img);
		}
		
		if (imagejpeg($thumbImage, $path_img, 100)){
			return $url_img;
		} else {
			return false;
		}
		 
	}
	
	private static function indexToCoords($index)
	{
	 global $tileWidth, $pxBetweenTiles, $leftOffSet, $topOffSet, $numberOfTiles;
	 
	 $x = ($index % 12) * ($tileWidth + $pxBetweenTiles) + $leftOffSet;
	 $y = floor($index / 12) * ($tileWidth + $pxBetweenTiles) + $topOffSet;
	 return Array($x, $y);
	}

    public function getInfo() {
        parent::getInfo();

        $this->favoritos_formateados = (array) json_decode($this->favoritos);
		
        if (is_array($this->favoritos_formateados) && sizeof($this->favoritos_formateados) > 0) {
            foreach ($this->favoritos_formateados as $kff => $ff) {
				if (is_object($ff))
					$ff = (array) $ff;
					
				if (is_array($ff))
                	$exp_ff = explode('.', $ff['id']);
				else
					$exp_ff = explode('.', $ff);
					
				$this->favoritos_formateados[$kff] = array();
				
                if (sizeof($exp_ff) == 3) {
					if (is_array($ff))
						$this->favoritos_formateados[$kff] = $ff;
					
					$this->favoritos_formateados[$kff]["ext"] = $kff;
                    $ext_com = new ExtCom(array("extension" => $exp_ff[0], "vista" => $exp_ff[1], "id_elemento" => $exp_ff[2]));

                    $this->favoritos_formateados[$kff]['conector'] = $ext_com->getData('array');
					
					if (empty($this->favoritos_formateados[$kff]['titulo']))
						$this->favoritos_formateados[$kff]['titulo'] = $ext_com->getData('array')['titulo'];
						
					if (empty($this->favoritos_formateados[$kff]['url']))
						$this->favoritos_formateados[$kff]['url'] = $ext_com->getData('array')['url'];
						
					if (empty($this->favoritos_formateados[$kff]['imagen']) && !empty($imagen_adaptador))
						$this->favoritos_formateados[$kff]['imagen'] = $imagen_adaptador;
						
				} elseif (sizeof($exp_ff) == 2) {
					if (is_array($ff))
						$this->favoritos_formateados[$kff] = $ff;
						
					$this->favoritos_formateados[$kff]["ext"] = $kff;
					$item_obj = Helpers::getExtensionsClasses('item', $exp_ff[0]);
                    $ext_com = new ExtCom(array("extension" => $exp_ff[0], "vista" => $item_obj[$exp_ff[0]]['vista'], "id_elemento" => $exp_ff[1]));

                    $this->favoritos_formateados[$kff]['conector'] = $ext_com->getData('array');
					
					if (empty($this->favoritos_formateados[$kff]['titulo']))
						$this->favoritos_formateados[$kff]['titulo'] = $ext_com->getData('array')['titulo'];
						
					if (empty($this->favoritos_formateados[$kff]['url']))
						$this->favoritos_formateados[$kff]['url'] = $ext_com->getData('array')['url'];
						
					$imagen_adaptador = $ext_com->getData('array')['obj']->getimagen_destacada(250,250);
						
					if (empty($this->favoritos_formateados[$kff]['imagen']) && !empty($imagen_adaptador))
						$this->favoritos_formateados[$kff]['imagen'] = $imagen_adaptador;
					
                } else {
                    unset($this->favoritos_formateados[$kff]);
                }
            }
        }
		
        $img_sm = $this->getimagen_destacada(32, 32);
        $img_md = $this->getimagen_destacada(250, 250);
        $img_lg = $this->getimagen_destacada(800, 800);

        if (empty($img_sm)) {
            $img_sm = Helpers::getImagenDesaparecida(50, 50);
            $img_md = Helpers::getImagenDesaparecida(300, 300);
            $img_lg = Helpers::getImagenDesaparecida(800, 800);
        }

        $this->imagenes->sm = $img_sm;
        $this->imagenes->md = $img_md;
        $this->imagenes->lg = $img_lg;
    }

    public function getCountListaFavoritosUsuario($uid = 0, $tipo = '') {
        if (empty($uid))
            return 0;

        $where = '';
        if (!empty($tipo)) {
            if ($tipo == 'privada') {
                $where = " AND publica='0'";
            } elseif ($tipo == 'publica') {
                $where = " AND publica='1'";
            }
        }

        $coms = new $this->ext_item_class();

        $coms_c = $coms->ListarCount("estado=1 AND creador='-" . $uid . "'" . $where);

        return $coms_c;
    }

    public function getListaFavoritosUsuario($uid = 0, $limit1 = 0, $limit2 = 0) {
        if (empty($uid))
            return false;
			
		if (isset($GLOBALS['listas_usuario'][$uid][$limit1.'.'.$limit2]))
			return $GLOBALS['listas_usuario'][$uid][$limit1.'.'.$limit2];

        $where = '';

        $coms = new $this->ext_item_class();

        $coms_c = $coms->ListarCount("estado=1 AND creador='-" . $uid . "'" . $where);

        if ($coms_c > 0) {
            $coms = $coms->Listar("estado=1 AND creador='-" . $uid . "'" . $where, "fecha", "DESC", $limit1, $limit2);
			
			$GLOBALS['listas_usuario'][$uid][$limit1.'.'.$limit2] = $coms;

            return $coms;
        } else {
            return false;
        }
    }

    public function getListasGuardadasUsuario($uid = 0) {
        if (empty($uid))
            return false;

        /* $coms = new FavoritoListaDinamicaSeguidor();

          $coms_c = $coms->ListarCount("usuario_id='".$uid."'","usuario_id","ASC");

          if ($coms_c > 0){
          $coms = $coms->Listar("usuario_id='".$uid."'","usuario_id","ASC");

          $arr_listas = array();
          foreach ($coms as $l){
          $tmp_obj = new self();
          $tmp_obj->setid($l->following_lista_id);

          if ($tmp_obj = $tmp_obj->BuscarId()){
          if ($tmp_obj->publica == '1' && !empty($tmp_obj->id)){
          $arr_listas[] = $tmp_obj;
          }
          }
          }

          Helpers::objectSort( $arr_listas, 'nombre', 'ASC' );

          return $arr_listas;
          } else {
          return false;
          } */
    }

}

?>